@@ -1,15 +1,20 @@
 package URI::Fast;
-$URI::Fast::VERSION = '0.21';
 # ABSTRACT: A fast(er) URI parser
-
-use utf8;
+$URI::Fast::VERSION = '0.22';
 use strict;
 use warnings;
 no strict 'refs';
+
 use Carp;
-use Inline;
 use Exporter;
-use Inline C => 'DATA', optimize => '-O2';
+
+use Inline
+  C        => 'DATA',
+  name     => 'URI::Fast',
+  version  => eval '$URI::Fast::VERSION',
+  optimize => '-O2';
+
+Inline->init;
 
 use parent 'Exporter';
 our @EXPORT_OK = qw(uri uri_split);
@@ -137,7 +142,7 @@ URI::Fast - A fast(er) URI parser
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
